@@ -9,6 +9,6 @@ def local():
     if not data:
         data = threading.local()
 
-    if not getattr(data, 'trace', None):
+    if not getattr(data, "trace", None):
         data.trace = TraceStack()
     return data.trace
